.. _recipe_asr.convex_hull:

asr.convex_hull
===============


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.convex_hull`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.convex_hull.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.convex_hull

or as a python module

.. code-block:: console

   $ python -m asr.convex_hull

Detailed description
--------------------
Convex hull stability analysis.

Steps
-----


asr.convex_hull
^^^^^^^^^^^^^^^
.. autofunction:: asr.convex_hull.main
   